==================================================
``cavcalc.output`` --- Storage of computed results
==================================================

.. automodule:: cavcalc.output

.. currentmodule:: cavcalc.output

Overview
========

.. autoclass:: Output

Properties
==========

.. autoattribute:: Output.computed

Methods
=======

.. rubric:: Obtaining results

.. automethod:: Output.get

.. rubric:: Plotting

.. automethod:: Output.plot
.. automethod:: Output.implot
